@@ -1,19 +1,28 @@
-/* liboil - Library of Optimized Inner Loops
- * Copyright (C) 2001,2002,2003  David A. Schleef <ds@schleef.org>
+/*
+ * LIBOIL - Library of Optimized Inner Loops
+ * Copyright (c) 2001,2002,2003,2004 David A. Schleef <ds@schleef.org>
+ * All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2.1 of the GNU Lesser General
- * Public License as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,8 +43,8 @@
 #define BLOCK8x8_S16(ptr, stride, row, column) \
 	(*((int16_t *)((void *)ptr + stride*row) + column))
 
-OIL_DEFINE_CLASS (idct8x8_f64, "double *dest, int dstr, double *src, int sstr");
-OIL_DEFINE_CLASS (idct8x8_s16, "int16_t *dest, int dstr, int16_t *src, int sstr");
+OIL_DEFINE_CLASS (idct8x8_f64, "double *d_8x8, int dstr, double *s_8x8, int sstr");
+OIL_DEFINE_CLASS (idct8x8_s16, "int16_t *d_8x8, int dstr, int16_t *s_8x8, int sstr");
 
 static void
 idct8x8_f64_slow (double *dest, int dstr, double *src, int sstr)
@@ -74,7 +83,7 @@ idct8x8_f64_slow (double *dest, int dstr, double *src, int sstr)
 	}
 }
 
-OIL_DEFINE_IMPL (idct8x8_f64_slow, idct8x8_f64);
+OIL_DEFINE_IMPL_REF (idct8x8_f64_slow, idct8x8_f64);
 
 #if defined(oil_idct8_f64)
 static void
@@ -111,7 +120,10 @@ idct8x8_s16_slow (int16_t *dest, int dstr, int16_t *src, int sstr)
 	oil_conv8x8_s16_f64 (dest,dstr,d,8*sizeof(double));
 }
 
+OIL_DEFINE_IMPL_REF (idct8x8_s16_slow, idct8x8_s16);
+#if 0
 OIL_DEFINE_IMPL_DEPENDS (idct8x8_s16_slow, idct8x8_s16,
     conv8x8_f64_s16, idct8x8_f64, conv8x8_s16_f64);
 #endif
+#endif
 
