@@ -1,19 +1,28 @@
-/* liboil - Library of Optimized Inner Loops
- * Copyright (C) 2004  David A. Schleef <ds@schleef.org>
+/*
+ * LIBOIL - Library of Optimized Inner Loops
+ * Copyright (c) 2004 David A. Schleef <ds@schleef.org>
+ * All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2.1 of the GNU Lesser General
- * Public License as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -185,7 +194,7 @@ md5_asm1(uint32_t *state, uint32_t *src)
 #undef STEP4
 
 
-OIL_DEFINE_IMPL_REF (md5_asm1, md5);
+OIL_DEFINE_IMPL_ASM (md5_asm1, md5);
 
 static void
 md5_asm2(uint32_t *state, uint32_t *src)
@@ -343,7 +352,7 @@ md5_asm2(uint32_t *state, uint32_t *src)
 }
 
 
-OIL_DEFINE_IMPL_REF (md5_asm2, md5);
+OIL_DEFINE_IMPL_ASM (md5_asm2, md5);
 
 static void
 md5_asm3(uint32_t *state, uint32_t *src)
@@ -508,5 +517,5 @@ md5_asm3(uint32_t *state, uint32_t *src)
 }
 
 
-OIL_DEFINE_IMPL_REF (md5_asm3, md5);
+OIL_DEFINE_IMPL_ASM (md5_asm3, md5);
 
